@@ -5,11 +5,11 @@ import matplotlib.pyplot as plt
 import pandas as pd
 import networkx as nx
 import seaborn as sns
-from .core import Grain, Boundary, Grains, Boundaries, Sample
+from .core import Grain, Boundary, Grains, Boundaries, Sample, Fractnet
 from .utils import deg, circular
 
 __author__ = 'Ondrej Lexa'
 __email__ = 'lexa.ondrej@gmail.com'
 
-__all__ = ['Grain', 'Boundary', 'Grains', 'Boundaries', 'Sample',
+__all__ = ['Grain', 'Boundary', 'Grains', 'Boundaries', 'Sample', 'Fractnet',
            'np', 'plt', 'pd', 'nx', 'sns', 'deg', 'circular']
